CATE
====

.. currentmodule:: pqp.identification

.. autoclass:: CATE
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CATE.control_vars
      ~CATE.expression

   .. rubric:: Methods Documentation

   .. automethod:: control_vars
   .. automethod:: expression
